@@ -124,4 +124,6 @@ class DEQueue(Primitive):
         
     def __len__(self):
         return len(self.List)
-        
+    
+    def __contains__(self, item):
+        return item in self.List
