@@ -240,3 +240,5 @@ class TaskQueue(Primitive):
     def __len__(self):
         return len(self.Queue)
 
+    def __contains__(self, item):
+        return item in self.Queue
